# data-gathering-lambda
import json
import urllib3
from datetime import datetime
import boto3

API_URL = 'https://api.coindesk.com/v1/bpi/currentprice.json'
BUCKET_NAME = 'rlovric-lambda-bucket'

def make_request(url):
    # funkcija koja radi GET request na url
    http = urllib3.PoolManager()
    try:
        resp = http.request('GET', url, headers={'Content-Type': 'application/json'})
    except:
        return None
    if resp.status == 200:
        return resp.data.decode('utf-8')
    return None


def lambda_handler(event, context):
    
    coindesk_data = make_request(API_URL)
    
    if not coindesk_data:
        return {'detail': f'Error while calling url: {API_URL}'}
        
    coindesk_json = json.loads(coindesk_data)
    
    # raščlanivanje datuma na godinu, mjesec, dan i sat
    date_string = coindesk_json['time']['updatedISO']
    date = datetime.strptime(date_string, '%Y-%m-%dT%H:%M:00+00:00')
    year = date.year
    month = date.month
    day = date.day
    hour = date.hour
    minute = date.minute
    
    # izrada imena datoteke ovisno o trenutnom vremenu
    # npr. ako je funkcija pozvana 13.9.2022. u 9h 
    # ime datoteke je '2022-09-13-09.json'
    coindesk_name = f'{year}-{month}-{day}-{hour}.json'
    
    # instanciranje S3 resursa iz boto3 biblioteke
    s3 = boto3.resource('s3')
    # instanciranje S3 objekta u našem bucketu, s generiranim imenom
    coindesk_s3object = s3.Object(BUCKET_NAME, coindesk_name)
    # spremanje objekta pomoću PUT metode
    coindesk_s3object.put(
        Body=(bytes(json.dumps(coindesk_json).encode('UTF-8')))
    )

    return {'object_details': str(coindesk_s3object)}
